@@ -7,7 +7,7 @@ from multiprocessing.managers import BaseManager
 
 
 from retry import retry
-from loger import makelog
+from loger import log
 
 
 class HubManager(BaseManager):
@@ -23,7 +23,7 @@ class Task():
     start_time = 0
     nodeId = 0
 
-    def __init__(self, key: str, priority: int, data: dict, task_type:str = ""):
+    def __init__(self, key: str, priority: int, data: dict, task_type: str = ""):
         """[初始化Task]
 
         Args:
@@ -35,7 +35,7 @@ class Task():
             TaskInitError: [初始化错误，检查数据格式与范围]
         """
         if isinstance(key, str) and isinstance(priority, int) and isinstance(data, dict)\
-             and isinstance(task_type,str) and 0 < priority < 1000000:
+                and isinstance(task_type, str) and 0 < priority < 1000000:
             self.key = key
             self.priority = priority if priority < 1000000 else 1000000
             self.data = data
@@ -88,7 +88,7 @@ class TaskHub():
         if not self.tasks.get(task.key):
             # 不存在则添加
             self.tasks[task.key] = task
-            makelog("task added!", 4)
+            log("task added!", 4)
             # 释放锁并返回
             self.release_lock()
             return True
@@ -97,7 +97,7 @@ class TaskHub():
             self.release_lock()
             raise TaskAlreadyExist()
 
-    def get(self, nodeId: int, filter_list : list = []):
+    def get(self, nodeId: int, filter_list: list = []):
         # 加锁
         self.get_lock()
         # 根据优先级排序 然后便利
@@ -161,11 +161,11 @@ class TaskHub():
                     # 输出状态
                     status_count = dict()
                     for key, task in self.tasks.items():
-                        status_count[task.status] = status_count[task.status] + 1 if status_count.get(task.status) else 1 
+                        status_count[task.status] = status_count[task.status] + 1 if status_count.get(task.status) else 1
                     status_str = ""
-                    for statu,amount in status_count.items():
-                        status_str += "{}:{}  ".format(statu,amount)
-                    makelog(status_str)
+                    for statu, amount in status_count.items():
+                        status_str += "{}:{}  ".format(statu, amount)
+                    log(status_str)
 
                     # 检查需要同步的数据
                     for_del_key = []
@@ -179,7 +179,7 @@ class TaskHub():
                         del self.tasks[key]
 
                 except:
-                    makelog("未知异常：{}".format(traceback.format_exc()), 1)
+                    log("未知异常：{}".format(traceback.format_exc()), 1)
 
                 finally:
                     # 释放锁
@@ -189,47 +189,47 @@ class TaskHub():
                 time.sleep(1)
 
     def get_lock(self):
-        # makelog("getting lock ....")
+        # log("getting lock ....")
         while self.lock:
             time.sleep(random.random())
         self.lock = True
-        # makelog("lock got!")
+        # log("lock got!")
 
     def release_lock(self):
         self.lock = False
-        # makelog("lock released!")
+        # log("lock released!")
 
 
 class TaskIdExitRequired(Exception):
-    def __str__(task):
+    def __str__(self, task):
         return "id is required for a task dict!{}".format(task)
 
 
 class TaskAlreadyExist(Exception):
-    def __str__(task_id):
-        return "task {} already exist! ".format(task_id)
+    def __str__(self):
+        return "task already exist! "
 
 
 class TaskNotExist(Exception):
-    def __str__():
+    def __str__(self, ):
         return "task not exist! "
 
 
 class TaskInitError(Exception):
-    def __str__(task_id):
+    def __str__(self):
         return "task pramar invalid! key:str priority:0<int<1000000 data:dict"
 
 
 class TaskNotRunning(Exception):
-    def __str__(self, task):
-        return "task should be running but it in {} now".format(task.status)
+    def __str__(self):
+        return "task should be running but it in {} now"
 
 
 class NodeIdTypeError(Exception):
-    def __str__(nodeId):
+    def __str__(self):
         return "nodeId must be int!"
 
 
 class NodeIdNotMatch(Exception):
-    def __str__(self, task_nodeId, nodeId):
-        return "nodeId doesn`t match! task nodeid = {} your node id = {}".format(task_nodeId, nodeId)
+    def __str__(self):
+        return "nodeId doesn`t match!"
