@@ -2,7 +2,7 @@ import requests
 
 from taskhub.server import serve
 from retry import retry
-from loger import makelog
+from loger import log
 import traceback
 
 
@@ -16,18 +16,18 @@ def sync(task):
         r.raise_for_status
         return r.json()
 
-    makelog("syncing...")
+    log("syncing...")
     try:
         r_data = req(task)
     except:
-        makelog("sync: req 时发生异常：{}".format(traceback.format_exc()), 1)
+        log("sync: req 时发生异常：{}".format(traceback.format_exc()), 1)
         return False
     else:
         if r_data.get("code") == 200:
-            makelog("synced!", 4)
+            log("synced!", 4)
             return True
         else:
-            makelog("sync: 返回状态异常：{}".format(r_data))
+            log("sync: 返回状态异常：{}".format(r_data))
             return False
 
 
